/*
 * Copyright (c) 2010-2015 Mark Allen.
 * 
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 * 
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package com.restfb.util;

import static com.restfb.util.DateUtils.toDateFromLongFormat;
import static com.restfb.util.DateUtils.toDateFromMonthYearFormat;
import static com.restfb.util.DateUtils.toDateFromShortFormat;
import java.util.Arrays;
import java.util.Collection;
import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertTrue;

import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;

/**
 * Unit tests that exercise {@link com.restfb.util.DateUtils}.
 * 
 * @author <a href="http://restfb.com">Mark Allen</a>
 */
@RunWith(Parameterized.class)
public class DateUtilsTest {

    private DateFormatStrategy expectedStrategy;
    
  @Parameterized.Parameters
  public static Collection strategies() {
    return Arrays.asList(new Object[][] { { new CachedDateFormatStrategy() }, { new SimpleDateFormatStrategy() } });
  }

  public DateUtilsTest(DateFormatStrategy strategy) {
    DateUtils.setDateFormatStrategy(strategy);
    expectedStrategy = strategy;
  }

  /**
   * Tests the "short" date format.
   */
  @Test
  public void shortDatesSimple() {
    assertTrue(toDateFromShortFormat("04/15/1984") != null);
    assertTrue(toDateFromShortFormat("01/01/1970") != null);
    assertTrue(toDateFromShortFormat("1970-09-15") != null);
    assertTrue(toDateFromShortFormat("junk") == null);
    assertEquals(expectedStrategy, DateUtils.getDateFormatStrategy());
  }

  /**
   * FB uses "long" date formats with and without timezones. Make sure we handle both gracefully.
   */
  @Test
  public void longDatesSimple() {
    assertTrue(toDateFromLongFormat("2011-12-22T21:00:00+0000") != null);
    assertTrue(toDateFromLongFormat("2011-12-22T21:00:00") != null);
    assertTrue(toDateFromLongFormat("1331784257") != null);
    assertTrue(toDateFromLongFormat("junk") == null);
    assertEquals(expectedStrategy, DateUtils.getDateFormatStrategy());
  }

  /**
   * Tests the "month and year" date format.
   */
  @Test
  public void monthYearDates() {
    assertTrue(toDateFromMonthYearFormat("2007-03") != null);
    assertTrue(toDateFromMonthYearFormat("2011-12") != null);
    assertTrue(toDateFromMonthYearFormat("0000-00") == null);
    assertTrue(toDateFromMonthYearFormat("junk") == null);
    assertEquals(expectedStrategy, DateUtils.getDateFormatStrategy());
  }
}